"""ConicalGearSetMultibodyDynamicsAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.mbd_analyses import _5440
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_CONICAL_GEAR_SET_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses",
    "ConicalGearSetMultibodyDynamicsAnalysis",
)

if TYPE_CHECKING:
    from mastapy.system_model.part_model.gears import _2524
    from mastapy.system_model.analyses_and_results.mbd_analyses import (
        _5382,
        _5391,
        _5396,
        _5444,
        _5452,
        _5455,
        _5458,
        _5492,
        _5498,
        _5501,
        _5522,
        _5489,
        _5376,
        _5467,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7549, _7545
    from mastapy.system_model.analyses_and_results import _2657, _2653, _2651


__docformat__ = "restructuredtext en"
__all__ = ("ConicalGearSetMultibodyDynamicsAnalysis",)


Self = TypeVar("Self", bound="ConicalGearSetMultibodyDynamicsAnalysis")


class ConicalGearSetMultibodyDynamicsAnalysis(_5440.GearSetMultibodyDynamicsAnalysis):
    """ConicalGearSetMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE = _CONICAL_GEAR_SET_MULTIBODY_DYNAMICS_ANALYSIS
    _CastSelf = TypeVar(
        "_CastSelf", bound="_Cast_ConicalGearSetMultibodyDynamicsAnalysis"
    )

    class _Cast_ConicalGearSetMultibodyDynamicsAnalysis:
        """Special nested class for casting ConicalGearSetMultibodyDynamicsAnalysis to subclasses."""

        def __init__(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
            parent: "ConicalGearSetMultibodyDynamicsAnalysis",
        ):
            self._parent = parent

        @property
        def gear_set_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_5440.GearSetMultibodyDynamicsAnalysis":
            return self._parent._cast(_5440.GearSetMultibodyDynamicsAnalysis)

        @property
        def specialised_assembly_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_5489.SpecialisedAssemblyMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5489

            return self._parent._cast(
                _5489.SpecialisedAssemblyMultibodyDynamicsAnalysis
            )

        @property
        def abstract_assembly_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_5376.AbstractAssemblyMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5376

            return self._parent._cast(_5376.AbstractAssemblyMultibodyDynamicsAnalysis)

        @property
        def part_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_5467.PartMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5467

            return self._parent._cast(_5467.PartMultibodyDynamicsAnalysis)

        @property
        def part_time_series_load_analysis_case(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_7549.PartTimeSeriesLoadAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7549

            return self._parent._cast(_7549.PartTimeSeriesLoadAnalysisCase)

        @property
        def part_analysis_case(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_7545.PartAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7545

            return self._parent._cast(_7545.PartAnalysisCase)

        @property
        def part_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_2657.PartAnalysis":
            from mastapy.system_model.analyses_and_results import _2657

            return self._parent._cast(_2657.PartAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_2653.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2653

            return self._parent._cast(_2653.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def agma_gleason_conical_gear_set_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_5382.AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5382

            return self._parent._cast(
                _5382.AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis
            )

        @property
        def bevel_differential_gear_set_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_5391.BevelDifferentialGearSetMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5391

            return self._parent._cast(
                _5391.BevelDifferentialGearSetMultibodyDynamicsAnalysis
            )

        @property
        def bevel_gear_set_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_5396.BevelGearSetMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5396

            return self._parent._cast(_5396.BevelGearSetMultibodyDynamicsAnalysis)

        @property
        def hypoid_gear_set_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_5444.HypoidGearSetMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5444

            return self._parent._cast(_5444.HypoidGearSetMultibodyDynamicsAnalysis)

        @property
        def klingelnberg_cyclo_palloid_conical_gear_set_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_5452.KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5452

            return self._parent._cast(
                _5452.KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis
            )

        @property
        def klingelnberg_cyclo_palloid_hypoid_gear_set_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_5455.KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5455

            return self._parent._cast(
                _5455.KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis
            )

        @property
        def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> (
            "_5458.KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis"
        ):
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5458

            return self._parent._cast(
                _5458.KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis
            )

        @property
        def spiral_bevel_gear_set_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_5492.SpiralBevelGearSetMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5492

            return self._parent._cast(_5492.SpiralBevelGearSetMultibodyDynamicsAnalysis)

        @property
        def straight_bevel_diff_gear_set_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_5498.StraightBevelDiffGearSetMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5498

            return self._parent._cast(
                _5498.StraightBevelDiffGearSetMultibodyDynamicsAnalysis
            )

        @property
        def straight_bevel_gear_set_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_5501.StraightBevelGearSetMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5501

            return self._parent._cast(
                _5501.StraightBevelGearSetMultibodyDynamicsAnalysis
            )

        @property
        def zerol_bevel_gear_set_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "_5522.ZerolBevelGearSetMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5522

            return self._parent._cast(_5522.ZerolBevelGearSetMultibodyDynamicsAnalysis)

        @property
        def conical_gear_set_multibody_dynamics_analysis(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
        ) -> "ConicalGearSetMultibodyDynamicsAnalysis":
            return self._parent

        def __getattr__(
            self: "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self, instance_to_wrap: "ConicalGearSetMultibodyDynamicsAnalysis.TYPE"
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self: Self) -> "_2524.ConicalGearSet":
        """mastapy.system_model.part_model.gears.ConicalGearSet

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "ConicalGearSetMultibodyDynamicsAnalysis._Cast_ConicalGearSetMultibodyDynamicsAnalysis":
        return self._Cast_ConicalGearSetMultibodyDynamicsAnalysis(self)



"""ShaftComplexShape"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List, Generic

from mastapy._math.vector_3d import Vector3D
from mastapy._internal import conversion
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_SHAFT_COMPLEX_SHAPE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.RotorDynamics", "ShaftComplexShape"
)

if TYPE_CHECKING:
    from mastapy.utility.units_and_measurements import _1605
    from mastapy.system_model.analyses_and_results.rotor_dynamics import (
        _4028,
        _4029,
        _4030,
        _4031,
    )


__docformat__ = "restructuredtext en"
__all__ = ("ShaftComplexShape",)


Self = TypeVar("Self", bound="ShaftComplexShape")
TLinearMeasurement = TypeVar("TLinearMeasurement", bound="_1605.MeasurementBase")
TAngularMeasurement = TypeVar("TAngularMeasurement", bound="_1605.MeasurementBase")


class ShaftComplexShape(_0.APIBase, Generic[TLinearMeasurement, TAngularMeasurement]):
    """ShaftComplexShape

    This is a mastapy class.

    Generic Types:
        TLinearMeasurement
        TAngularMeasurement
    """

    TYPE = _SHAFT_COMPLEX_SHAPE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_ShaftComplexShape")

    class _Cast_ShaftComplexShape:
        """Special nested class for casting ShaftComplexShape to subclasses."""

        def __init__(
            self: "ShaftComplexShape._Cast_ShaftComplexShape",
            parent: "ShaftComplexShape",
        ):
            self._parent = parent

        @property
        def shaft_forced_complex_shape(
            self: "ShaftComplexShape._Cast_ShaftComplexShape",
        ) -> "_4028.ShaftForcedComplexShape":
            from mastapy.system_model.analyses_and_results.rotor_dynamics import _4028

            return self._parent._cast(_4028.ShaftForcedComplexShape)

        @property
        def shaft_modal_complex_shape(
            self: "ShaftComplexShape._Cast_ShaftComplexShape",
        ) -> "_4029.ShaftModalComplexShape":
            from mastapy.system_model.analyses_and_results.rotor_dynamics import _4029

            return self._parent._cast(_4029.ShaftModalComplexShape)

        @property
        def shaft_modal_complex_shape_at_speeds(
            self: "ShaftComplexShape._Cast_ShaftComplexShape",
        ) -> "_4030.ShaftModalComplexShapeAtSpeeds":
            from mastapy.system_model.analyses_and_results.rotor_dynamics import _4030

            return self._parent._cast(_4030.ShaftModalComplexShapeAtSpeeds)

        @property
        def shaft_modal_complex_shape_at_stiffness(
            self: "ShaftComplexShape._Cast_ShaftComplexShape",
        ) -> "_4031.ShaftModalComplexShapeAtStiffness":
            from mastapy.system_model.analyses_and_results.rotor_dynamics import _4031

            return self._parent._cast(_4031.ShaftModalComplexShapeAtStiffness)

        @property
        def shaft_complex_shape(
            self: "ShaftComplexShape._Cast_ShaftComplexShape",
        ) -> "ShaftComplexShape":
            return self._parent

        def __getattr__(self: "ShaftComplexShape._Cast_ShaftComplexShape", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "ShaftComplexShape.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def angular_imaginary(self: Self) -> "List[Vector3D]":
        """List[Vector3D]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AngularImaginary

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, Vector3D)

        if value is None:
            return None

        return value

    @property
    def angular_magnitude(self: Self) -> "List[Vector3D]":
        """List[Vector3D]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AngularMagnitude

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, Vector3D)

        if value is None:
            return None

        return value

    @property
    def angular_phase(self: Self) -> "List[Vector3D]":
        """List[Vector3D]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AngularPhase

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, Vector3D)

        if value is None:
            return None

        return value

    @property
    def angular_real(self: Self) -> "List[Vector3D]":
        """List[Vector3D]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AngularReal

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, Vector3D)

        if value is None:
            return None

        return value

    @property
    def linear_imaginary(self: Self) -> "List[Vector3D]":
        """List[Vector3D]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LinearImaginary

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, Vector3D)

        if value is None:
            return None

        return value

    @property
    def linear_magnitude(self: Self) -> "List[Vector3D]":
        """List[Vector3D]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LinearMagnitude

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, Vector3D)

        if value is None:
            return None

        return value

    @property
    def linear_phase(self: Self) -> "List[Vector3D]":
        """List[Vector3D]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LinearPhase

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, Vector3D)

        if value is None:
            return None

        return value

    @property
    def linear_real(self: Self) -> "List[Vector3D]":
        """List[Vector3D]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LinearReal

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, Vector3D)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: Self) -> "ShaftComplexShape._Cast_ShaftComplexShape":
        return self._Cast_ShaftComplexShape(self)



"""ElectricMachineLoadCase"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal.implicit import enum_with_selected_value
from mastapy.nodal_analysis.elmer import _169
from mastapy._internal import enum_with_selected_value_runtime, conversion, constructor
from mastapy.electric_machines.load_cases_and_analyses import _1358
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ELECTRIC_MACHINE_LOAD_CASE = python_net_import(
    "SMT.MastaAPI.ElectricMachines.LoadCasesAndAnalyses", "ElectricMachineLoadCase"
)

if TYPE_CHECKING:
    from mastapy.electric_machines.load_cases_and_analyses import _1361, _1355, _1375
    from mastapy.electric_machines import _1266


__docformat__ = "restructuredtext en"
__all__ = ("ElectricMachineLoadCase",)


Self = TypeVar("Self", bound="ElectricMachineLoadCase")


class ElectricMachineLoadCase(_1358.ElectricMachineLoadCaseBase):
    """ElectricMachineLoadCase

    This is a mastapy class.
    """

    TYPE = _ELECTRIC_MACHINE_LOAD_CASE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_ElectricMachineLoadCase")

    class _Cast_ElectricMachineLoadCase:
        """Special nested class for casting ElectricMachineLoadCase to subclasses."""

        def __init__(
            self: "ElectricMachineLoadCase._Cast_ElectricMachineLoadCase",
            parent: "ElectricMachineLoadCase",
        ):
            self._parent = parent

        @property
        def electric_machine_load_case_base(
            self: "ElectricMachineLoadCase._Cast_ElectricMachineLoadCase",
        ) -> "_1358.ElectricMachineLoadCaseBase":
            return self._parent._cast(_1358.ElectricMachineLoadCaseBase)

        @property
        def speed_torque_load_case(
            self: "ElectricMachineLoadCase._Cast_ElectricMachineLoadCase",
        ) -> "_1375.SpeedTorqueLoadCase":
            from mastapy.electric_machines.load_cases_and_analyses import _1375

            return self._parent._cast(_1375.SpeedTorqueLoadCase)

        @property
        def electric_machine_load_case(
            self: "ElectricMachineLoadCase._Cast_ElectricMachineLoadCase",
        ) -> "ElectricMachineLoadCase":
            return self._parent

        def __getattr__(
            self: "ElectricMachineLoadCase._Cast_ElectricMachineLoadCase", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "ElectricMachineLoadCase.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def analysis_period(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_ElectricMachineAnalysisPeriod":
        """EnumWithSelectedValue[mastapy.nodal_analysis.elmer.ElectricMachineAnalysisPeriod]"""
        temp = self.wrapped.AnalysisPeriod

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_ElectricMachineAnalysisPeriod.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @analysis_period.setter
    @enforce_parameter_types
    def analysis_period(self: Self, value: "_169.ElectricMachineAnalysisPeriod"):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_ElectricMachineAnalysisPeriod.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.AnalysisPeriod = value

    @property
    def core_loss_minor_loop_hysteresis_loss_factor(self: Self) -> "float":
        """float"""
        temp = self.wrapped.CoreLossMinorLoopHysteresisLossFactor

        if temp is None:
            return 0.0

        return temp

    @core_loss_minor_loop_hysteresis_loss_factor.setter
    @enforce_parameter_types
    def core_loss_minor_loop_hysteresis_loss_factor(self: Self, value: "float"):
        self.wrapped.CoreLossMinorLoopHysteresisLossFactor = (
            float(value) if value is not None else 0.0
        )

    @property
    def current_angle(self: Self) -> "float":
        """float"""
        temp = self.wrapped.CurrentAngle

        if temp is None:
            return 0.0

        return temp

    @current_angle.setter
    @enforce_parameter_types
    def current_angle(self: Self, value: "float"):
        self.wrapped.CurrentAngle = float(value) if value is not None else 0.0

    @property
    def end_winding_inductance_method(self: Self) -> "_1361.EndWindingInductanceMethod":
        """mastapy.electric_machines.load_cases_and_analyses.EndWindingInductanceMethod"""
        temp = self.wrapped.EndWindingInductanceMethod

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.ElectricMachines.LoadCasesAndAnalyses.EndWindingInductanceMethod",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.electric_machines.load_cases_and_analyses._1361",
            "EndWindingInductanceMethod",
        )(value)

    @end_winding_inductance_method.setter
    @enforce_parameter_types
    def end_winding_inductance_method(
        self: Self, value: "_1361.EndWindingInductanceMethod"
    ):
        value = conversion.mp_to_pn_enum(
            value,
            "SMT.MastaAPI.ElectricMachines.LoadCasesAndAnalyses.EndWindingInductanceMethod",
        )
        self.wrapped.EndWindingInductanceMethod = value

    @property
    def include_iron_and_eddy_current_losses(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.IncludeIronAndEddyCurrentLosses

        if temp is None:
            return False

        return temp

    @include_iron_and_eddy_current_losses.setter
    @enforce_parameter_types
    def include_iron_and_eddy_current_losses(self: Self, value: "bool"):
        self.wrapped.IncludeIronAndEddyCurrentLosses = (
            bool(value) if value is not None else False
        )

    @property
    def include_open_circuit_calculation(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.IncludeOpenCircuitCalculation

        if temp is None:
            return False

        return temp

    @include_open_circuit_calculation.setter
    @enforce_parameter_types
    def include_open_circuit_calculation(self: Self, value: "bool"):
        self.wrapped.IncludeOpenCircuitCalculation = (
            bool(value) if value is not None else False
        )

    @property
    def include_winding_ac_losses(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.IncludeWindingACLosses

        if temp is None:
            return False

        return temp

    @include_winding_ac_losses.setter
    @enforce_parameter_types
    def include_winding_ac_losses(self: Self, value: "bool"):
        self.wrapped.IncludeWindingACLosses = (
            bool(value) if value is not None else False
        )

    @property
    def minimum_number_of_steps_for_voltages_and_losses_calculation(
        self: Self,
    ) -> "int":
        """int"""
        temp = self.wrapped.MinimumNumberOfStepsForVoltagesAndLossesCalculation

        if temp is None:
            return 0

        return temp

    @minimum_number_of_steps_for_voltages_and_losses_calculation.setter
    @enforce_parameter_types
    def minimum_number_of_steps_for_voltages_and_losses_calculation(
        self: Self, value: "int"
    ):
        self.wrapped.MinimumNumberOfStepsForVoltagesAndLossesCalculation = (
            int(value) if value is not None else 0
        )

    @property
    def non_linear_relaxation_factor(self: Self) -> "float":
        """float"""
        temp = self.wrapped.NonLinearRelaxationFactor

        if temp is None:
            return 0.0

        return temp

    @non_linear_relaxation_factor.setter
    @enforce_parameter_types
    def non_linear_relaxation_factor(self: Self, value: "float"):
        self.wrapped.NonLinearRelaxationFactor = (
            float(value) if value is not None else 0.0
        )

    @property
    def non_linear_system_convergence_tolerance(self: Self) -> "float":
        """float"""
        temp = self.wrapped.NonLinearSystemConvergenceTolerance

        if temp is None:
            return 0.0

        return temp

    @non_linear_system_convergence_tolerance.setter
    @enforce_parameter_types
    def non_linear_system_convergence_tolerance(self: Self, value: "float"):
        self.wrapped.NonLinearSystemConvergenceTolerance = (
            float(value) if value is not None else 0.0
        )

    @property
    def non_linear_system_maximum_number_of_iterations(self: Self) -> "int":
        """int"""
        temp = self.wrapped.NonLinearSystemMaximumNumberOfIterations

        if temp is None:
            return 0

        return temp

    @non_linear_system_maximum_number_of_iterations.setter
    @enforce_parameter_types
    def non_linear_system_maximum_number_of_iterations(self: Self, value: "int"):
        self.wrapped.NonLinearSystemMaximumNumberOfIterations = (
            int(value) if value is not None else 0
        )

    @property
    def number_of_cycles(self: Self) -> "int":
        """int"""
        temp = self.wrapped.NumberOfCycles

        if temp is None:
            return 0

        return temp

    @number_of_cycles.setter
    @enforce_parameter_types
    def number_of_cycles(self: Self, value: "int"):
        self.wrapped.NumberOfCycles = int(value) if value is not None else 0

    @property
    def number_of_initial_transient_steps(self: Self) -> "int":
        """int"""
        temp = self.wrapped.NumberOfInitialTransientSteps

        if temp is None:
            return 0

        return temp

    @number_of_initial_transient_steps.setter
    @enforce_parameter_types
    def number_of_initial_transient_steps(self: Self, value: "int"):
        self.wrapped.NumberOfInitialTransientSteps = (
            int(value) if value is not None else 0
        )

    @property
    def number_of_steps_per_analysis_period(self: Self) -> "int":
        """int"""
        temp = self.wrapped.NumberOfStepsPerAnalysisPeriod

        if temp is None:
            return 0

        return temp

    @number_of_steps_per_analysis_period.setter
    @enforce_parameter_types
    def number_of_steps_per_analysis_period(self: Self, value: "int"):
        self.wrapped.NumberOfStepsPerAnalysisPeriod = (
            int(value) if value is not None else 0
        )

    @property
    def override_design_end_winding_inductance_method(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.OverrideDesignEndWindingInductanceMethod

        if temp is None:
            return False

        return temp

    @override_design_end_winding_inductance_method.setter
    @enforce_parameter_types
    def override_design_end_winding_inductance_method(self: Self, value: "bool"):
        self.wrapped.OverrideDesignEndWindingInductanceMethod = (
            bool(value) if value is not None else False
        )

    @property
    def peak_line_current(self: Self) -> "float":
        """float"""
        temp = self.wrapped.PeakLineCurrent

        if temp is None:
            return 0.0

        return temp

    @peak_line_current.setter
    @enforce_parameter_types
    def peak_line_current(self: Self, value: "float"):
        self.wrapped.PeakLineCurrent = float(value) if value is not None else 0.0

    @property
    def rms_line_current(self: Self) -> "float":
        """float"""
        temp = self.wrapped.RMSLineCurrent

        if temp is None:
            return 0.0

        return temp

    @rms_line_current.setter
    @enforce_parameter_types
    def rms_line_current(self: Self, value: "float"):
        self.wrapped.RMSLineCurrent = float(value) if value is not None else 0.0

    @property
    def speed(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Speed

        if temp is None:
            return 0.0

        return temp

    @speed.setter
    @enforce_parameter_types
    def speed(self: Self, value: "float"):
        self.wrapped.Speed = float(value) if value is not None else 0.0

    @property
    def total_number_of_time_steps(self: Self) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TotalNumberOfTimeSteps

        if temp is None:
            return 0

        return temp

    @property
    def user_specified_end_winding_inductance(self: Self) -> "float":
        """float"""
        temp = self.wrapped.UserSpecifiedEndWindingInductance

        if temp is None:
            return 0.0

        return temp

    @user_specified_end_winding_inductance.setter
    @enforce_parameter_types
    def user_specified_end_winding_inductance(self: Self, value: "float"):
        self.wrapped.UserSpecifiedEndWindingInductance = (
            float(value) if value is not None else 0.0
        )

    @enforce_parameter_types
    def analysis_for(
        self: Self, setup: "_1266.ElectricMachineSetup"
    ) -> "_1355.ElectricMachineFEAnalysis":
        """mastapy.electric_machines.load_cases_and_analyses.ElectricMachineFEAnalysis

        Args:
            setup (mastapy.electric_machines.ElectricMachineSetup)
        """
        method_result = self.wrapped.AnalysisFor(setup.wrapped if setup else None)
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @property
    def cast_to(self: Self) -> "ElectricMachineLoadCase._Cast_ElectricMachineLoadCase":
        return self._Cast_ElectricMachineLoadCase(self)



"""WormGearDutyCycleRating"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import constructor, conversion
from mastapy.gears.rating import _358
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_WORM_GEAR_DUTY_CYCLE_RATING = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Worm", "WormGearDutyCycleRating"
)

if TYPE_CHECKING:
    from mastapy.gears.rating import _359, _354
    from mastapy.gears.rating.worm import _375, _374
    from mastapy.gears.analysis import _1215


__docformat__ = "restructuredtext en"
__all__ = ("WormGearDutyCycleRating",)


Self = TypeVar("Self", bound="WormGearDutyCycleRating")


class WormGearDutyCycleRating(_358.GearDutyCycleRating):
    """WormGearDutyCycleRating

    This is a mastapy class.
    """

    TYPE = _WORM_GEAR_DUTY_CYCLE_RATING
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_WormGearDutyCycleRating")

    class _Cast_WormGearDutyCycleRating:
        """Special nested class for casting WormGearDutyCycleRating to subclasses."""

        def __init__(
            self: "WormGearDutyCycleRating._Cast_WormGearDutyCycleRating",
            parent: "WormGearDutyCycleRating",
        ):
            self._parent = parent

        @property
        def gear_duty_cycle_rating(
            self: "WormGearDutyCycleRating._Cast_WormGearDutyCycleRating",
        ) -> "_358.GearDutyCycleRating":
            return self._parent._cast(_358.GearDutyCycleRating)

        @property
        def abstract_gear_rating(
            self: "WormGearDutyCycleRating._Cast_WormGearDutyCycleRating",
        ) -> "_354.AbstractGearRating":
            from mastapy.gears.rating import _354

            return self._parent._cast(_354.AbstractGearRating)

        @property
        def abstract_gear_analysis(
            self: "WormGearDutyCycleRating._Cast_WormGearDutyCycleRating",
        ) -> "_1215.AbstractGearAnalysis":
            from mastapy.gears.analysis import _1215

            return self._parent._cast(_1215.AbstractGearAnalysis)

        @property
        def worm_gear_duty_cycle_rating(
            self: "WormGearDutyCycleRating._Cast_WormGearDutyCycleRating",
        ) -> "WormGearDutyCycleRating":
            return self._parent

        def __getattr__(
            self: "WormGearDutyCycleRating._Cast_WormGearDutyCycleRating", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "WormGearDutyCycleRating.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def left_flank_rating(self: Self) -> "_359.GearFlankRating":
        """mastapy.gears.rating.GearFlankRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LeftFlankRating

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def right_flank_rating(self: Self) -> "_359.GearFlankRating":
        """mastapy.gears.rating.GearFlankRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RightFlankRating

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def gear_set_design_duty_cycle(self: Self) -> "_375.WormGearSetDutyCycleRating":
        """mastapy.gears.rating.worm.WormGearSetDutyCycleRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearSetDesignDutyCycle

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def worm_gear_set_design_duty_cycle(
        self: Self,
    ) -> "_375.WormGearSetDutyCycleRating":
        """mastapy.gears.rating.worm.WormGearSetDutyCycleRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WormGearSetDesignDutyCycle

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def gear_ratings(self: Self) -> "List[_374.WormGearRating]":
        """List[mastapy.gears.rating.worm.WormGearRating]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearRatings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def worm_gear_ratings(self: Self) -> "List[_374.WormGearRating]":
        """List[mastapy.gears.rating.worm.WormGearRating]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WormGearRatings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: Self) -> "WormGearDutyCycleRating._Cast_WormGearDutyCycleRating":
        return self._Cast_WormGearDutyCycleRating(self)



"""DudleyEffectiveLengthApproximationOption"""

from __future__ import annotations

from typing import TypeVar, Any
from enum import Enum

from mastapy._internal.python_net import python_net_import

_DUDLEY_EFFECTIVE_LENGTH_APPROXIMATION_OPTION = python_net_import(
    "SMT.MastaAPI.DetailedRigidConnectors.Splines",
    "DudleyEffectiveLengthApproximationOption",
)


__docformat__ = "restructuredtext en"
__all__ = ("DudleyEffectiveLengthApproximationOption",)


Self = TypeVar("Self", bound="DudleyEffectiveLengthApproximationOption")


class DudleyEffectiveLengthApproximationOption(Enum):
    """DudleyEffectiveLengthApproximationOption

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls):
        return _DUDLEY_EFFECTIVE_LENGTH_APPROXIMATION_OPTION

    FOR_MAXIMUM_MISALIGNMENT = 0
    FOR_MODERATE_MISALIGNMENT = 1
    FOR_FLEXIBLE_SPLINES = 2
    FOR_FIXED_SPLINES_WITH_HELIX_MODIFICATION = 3
    FOR_FIXED_SPLINES_WITHOUT_HELIX_MODIFICATION = 4


def __enum_setattr(self: Self, attr: str, value: Any):
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: Self, attr: str):
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


DudleyEffectiveLengthApproximationOption.__setattr__ = __enum_setattr
DudleyEffectiveLengthApproximationOption.__delattr__ = __enum_delattr



"""HobbingProcessSimulationInput"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal.implicit import enum_with_selected_value
from mastapy.gears.manufacturing.cylindrical.hobbing_process_simulation_new import (
    _658,
    _685,
)
from mastapy._internal import enum_with_selected_value_runtime, conversion, constructor
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_HOBBING_PROCESS_SIMULATION_INPUT = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.HobbingProcessSimulationNew",
    "HobbingProcessSimulationInput",
)

if TYPE_CHECKING:
    from mastapy.gears.manufacturing.cylindrical.hobbing_process_simulation_new import (
        _676,
        _677,
    )


__docformat__ = "restructuredtext en"
__all__ = ("HobbingProcessSimulationInput",)


Self = TypeVar("Self", bound="HobbingProcessSimulationInput")


class HobbingProcessSimulationInput(_685.ProcessSimulationInput):
    """HobbingProcessSimulationInput

    This is a mastapy class.
    """

    TYPE = _HOBBING_PROCESS_SIMULATION_INPUT
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_HobbingProcessSimulationInput")

    class _Cast_HobbingProcessSimulationInput:
        """Special nested class for casting HobbingProcessSimulationInput to subclasses."""

        def __init__(
            self: "HobbingProcessSimulationInput._Cast_HobbingProcessSimulationInput",
            parent: "HobbingProcessSimulationInput",
        ):
            self._parent = parent

        @property
        def process_simulation_input(
            self: "HobbingProcessSimulationInput._Cast_HobbingProcessSimulationInput",
        ) -> "_685.ProcessSimulationInput":
            return self._parent._cast(_685.ProcessSimulationInput)

        @property
        def hobbing_process_simulation_input(
            self: "HobbingProcessSimulationInput._Cast_HobbingProcessSimulationInput",
        ) -> "HobbingProcessSimulationInput":
            return self._parent

        def __getattr__(
            self: "HobbingProcessSimulationInput._Cast_HobbingProcessSimulationInput",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "HobbingProcessSimulationInput.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def process_method(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_ActiveProcessMethod":
        """EnumWithSelectedValue[mastapy.gears.manufacturing.cylindrical.hobbing_process_simulation_new.ActiveProcessMethod]"""
        temp = self.wrapped.ProcessMethod

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_ActiveProcessMethod.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @process_method.setter
    @enforce_parameter_types
    def process_method(self: Self, value: "_658.ActiveProcessMethod"):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_ActiveProcessMethod.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.ProcessMethod = value

    @property
    def hob_manufacture_error(self: Self) -> "_676.HobManufactureError":
        """mastapy.gears.manufacturing.cylindrical.hobbing_process_simulation_new.HobManufactureError

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HobManufactureError

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def hob_resharpening_error(self: Self) -> "_677.HobResharpeningError":
        """mastapy.gears.manufacturing.cylindrical.hobbing_process_simulation_new.HobResharpeningError

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HobResharpeningError

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "HobbingProcessSimulationInput._Cast_HobbingProcessSimulationInput":
        return self._Cast_HobbingProcessSimulationInput(self)



"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._4167 import AbstractAssemblyCompoundPowerFlow
    from ._4168 import AbstractShaftCompoundPowerFlow
    from ._4169 import AbstractShaftOrHousingCompoundPowerFlow
    from ._4170 import AbstractShaftToMountableComponentConnectionCompoundPowerFlow
    from ._4171 import AGMAGleasonConicalGearCompoundPowerFlow
    from ._4172 import AGMAGleasonConicalGearMeshCompoundPowerFlow
    from ._4173 import AGMAGleasonConicalGearSetCompoundPowerFlow
    from ._4174 import AssemblyCompoundPowerFlow
    from ._4175 import BearingCompoundPowerFlow
    from ._4176 import BeltConnectionCompoundPowerFlow
    from ._4177 import BeltDriveCompoundPowerFlow
    from ._4178 import BevelDifferentialGearCompoundPowerFlow
    from ._4179 import BevelDifferentialGearMeshCompoundPowerFlow
    from ._4180 import BevelDifferentialGearSetCompoundPowerFlow
    from ._4181 import BevelDifferentialPlanetGearCompoundPowerFlow
    from ._4182 import BevelDifferentialSunGearCompoundPowerFlow
    from ._4183 import BevelGearCompoundPowerFlow
    from ._4184 import BevelGearMeshCompoundPowerFlow
    from ._4185 import BevelGearSetCompoundPowerFlow
    from ._4186 import BoltCompoundPowerFlow
    from ._4187 import BoltedJointCompoundPowerFlow
    from ._4188 import ClutchCompoundPowerFlow
    from ._4189 import ClutchConnectionCompoundPowerFlow
    from ._4190 import ClutchHalfCompoundPowerFlow
    from ._4191 import CoaxialConnectionCompoundPowerFlow
    from ._4192 import ComponentCompoundPowerFlow
    from ._4193 import ConceptCouplingCompoundPowerFlow
    from ._4194 import ConceptCouplingConnectionCompoundPowerFlow
    from ._4195 import ConceptCouplingHalfCompoundPowerFlow
    from ._4196 import ConceptGearCompoundPowerFlow
    from ._4197 import ConceptGearMeshCompoundPowerFlow
    from ._4198 import ConceptGearSetCompoundPowerFlow
    from ._4199 import ConicalGearCompoundPowerFlow
    from ._4200 import ConicalGearMeshCompoundPowerFlow
    from ._4201 import ConicalGearSetCompoundPowerFlow
    from ._4202 import ConnectionCompoundPowerFlow
    from ._4203 import ConnectorCompoundPowerFlow
    from ._4204 import CouplingCompoundPowerFlow
    from ._4205 import CouplingConnectionCompoundPowerFlow
    from ._4206 import CouplingHalfCompoundPowerFlow
    from ._4207 import CVTBeltConnectionCompoundPowerFlow
    from ._4208 import CVTCompoundPowerFlow
    from ._4209 import CVTPulleyCompoundPowerFlow
    from ._4210 import CycloidalAssemblyCompoundPowerFlow
    from ._4211 import CycloidalDiscCentralBearingConnectionCompoundPowerFlow
    from ._4212 import CycloidalDiscCompoundPowerFlow
    from ._4213 import CycloidalDiscPlanetaryBearingConnectionCompoundPowerFlow
    from ._4214 import CylindricalGearCompoundPowerFlow
    from ._4215 import CylindricalGearMeshCompoundPowerFlow
    from ._4216 import CylindricalGearSetCompoundPowerFlow
    from ._4217 import CylindricalPlanetGearCompoundPowerFlow
    from ._4218 import DatumCompoundPowerFlow
    from ._4219 import ExternalCADModelCompoundPowerFlow
    from ._4220 import FaceGearCompoundPowerFlow
    from ._4221 import FaceGearMeshCompoundPowerFlow
    from ._4222 import FaceGearSetCompoundPowerFlow
    from ._4223 import FEPartCompoundPowerFlow
    from ._4224 import FlexiblePinAssemblyCompoundPowerFlow
    from ._4225 import GearCompoundPowerFlow
    from ._4226 import GearMeshCompoundPowerFlow
    from ._4227 import GearSetCompoundPowerFlow
    from ._4228 import GuideDxfModelCompoundPowerFlow
    from ._4229 import HypoidGearCompoundPowerFlow
    from ._4230 import HypoidGearMeshCompoundPowerFlow
    from ._4231 import HypoidGearSetCompoundPowerFlow
    from ._4232 import InterMountableComponentConnectionCompoundPowerFlow
    from ._4233 import KlingelnbergCycloPalloidConicalGearCompoundPowerFlow
    from ._4234 import KlingelnbergCycloPalloidConicalGearMeshCompoundPowerFlow
    from ._4235 import KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow
    from ._4236 import KlingelnbergCycloPalloidHypoidGearCompoundPowerFlow
    from ._4237 import KlingelnbergCycloPalloidHypoidGearMeshCompoundPowerFlow
    from ._4238 import KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow
    from ._4239 import KlingelnbergCycloPalloidSpiralBevelGearCompoundPowerFlow
    from ._4240 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundPowerFlow
    from ._4241 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow
    from ._4242 import MassDiscCompoundPowerFlow
    from ._4243 import MeasurementComponentCompoundPowerFlow
    from ._4244 import MountableComponentCompoundPowerFlow
    from ._4245 import OilSealCompoundPowerFlow
    from ._4246 import PartCompoundPowerFlow
    from ._4247 import PartToPartShearCouplingCompoundPowerFlow
    from ._4248 import PartToPartShearCouplingConnectionCompoundPowerFlow
    from ._4249 import PartToPartShearCouplingHalfCompoundPowerFlow
    from ._4250 import PlanetaryConnectionCompoundPowerFlow
    from ._4251 import PlanetaryGearSetCompoundPowerFlow
    from ._4252 import PlanetCarrierCompoundPowerFlow
    from ._4253 import PointLoadCompoundPowerFlow
    from ._4254 import PowerLoadCompoundPowerFlow
    from ._4255 import PulleyCompoundPowerFlow
    from ._4256 import RingPinsCompoundPowerFlow
    from ._4257 import RingPinsToDiscConnectionCompoundPowerFlow
    from ._4258 import RollingRingAssemblyCompoundPowerFlow
    from ._4259 import RollingRingCompoundPowerFlow
    from ._4260 import RollingRingConnectionCompoundPowerFlow
    from ._4261 import RootAssemblyCompoundPowerFlow
    from ._4262 import ShaftCompoundPowerFlow
    from ._4263 import ShaftHubConnectionCompoundPowerFlow
    from ._4264 import ShaftToMountableComponentConnectionCompoundPowerFlow
    from ._4265 import SpecialisedAssemblyCompoundPowerFlow
    from ._4266 import SpiralBevelGearCompoundPowerFlow
    from ._4267 import SpiralBevelGearMeshCompoundPowerFlow
    from ._4268 import SpiralBevelGearSetCompoundPowerFlow
    from ._4269 import SpringDamperCompoundPowerFlow
    from ._4270 import SpringDamperConnectionCompoundPowerFlow
    from ._4271 import SpringDamperHalfCompoundPowerFlow
    from ._4272 import StraightBevelDiffGearCompoundPowerFlow
    from ._4273 import StraightBevelDiffGearMeshCompoundPowerFlow
    from ._4274 import StraightBevelDiffGearSetCompoundPowerFlow
    from ._4275 import StraightBevelGearCompoundPowerFlow
    from ._4276 import StraightBevelGearMeshCompoundPowerFlow
    from ._4277 import StraightBevelGearSetCompoundPowerFlow
    from ._4278 import StraightBevelPlanetGearCompoundPowerFlow
    from ._4279 import StraightBevelSunGearCompoundPowerFlow
    from ._4280 import SynchroniserCompoundPowerFlow
    from ._4281 import SynchroniserHalfCompoundPowerFlow
    from ._4282 import SynchroniserPartCompoundPowerFlow
    from ._4283 import SynchroniserSleeveCompoundPowerFlow
    from ._4284 import TorqueConverterCompoundPowerFlow
    from ._4285 import TorqueConverterConnectionCompoundPowerFlow
    from ._4286 import TorqueConverterPumpCompoundPowerFlow
    from ._4287 import TorqueConverterTurbineCompoundPowerFlow
    from ._4288 import UnbalancedMassCompoundPowerFlow
    from ._4289 import VirtualComponentCompoundPowerFlow
    from ._4290 import WormGearCompoundPowerFlow
    from ._4291 import WormGearMeshCompoundPowerFlow
    from ._4292 import WormGearSetCompoundPowerFlow
    from ._4293 import ZerolBevelGearCompoundPowerFlow
    from ._4294 import ZerolBevelGearMeshCompoundPowerFlow
    from ._4295 import ZerolBevelGearSetCompoundPowerFlow
else:
    import_structure = {
        "_4167": ["AbstractAssemblyCompoundPowerFlow"],
        "_4168": ["AbstractShaftCompoundPowerFlow"],
        "_4169": ["AbstractShaftOrHousingCompoundPowerFlow"],
        "_4170": ["AbstractShaftToMountableComponentConnectionCompoundPowerFlow"],
        "_4171": ["AGMAGleasonConicalGearCompoundPowerFlow"],
        "_4172": ["AGMAGleasonConicalGearMeshCompoundPowerFlow"],
        "_4173": ["AGMAGleasonConicalGearSetCompoundPowerFlow"],
        "_4174": ["AssemblyCompoundPowerFlow"],
        "_4175": ["BearingCompoundPowerFlow"],
        "_4176": ["BeltConnectionCompoundPowerFlow"],
        "_4177": ["BeltDriveCompoundPowerFlow"],
        "_4178": ["BevelDifferentialGearCompoundPowerFlow"],
        "_4179": ["BevelDifferentialGearMeshCompoundPowerFlow"],
        "_4180": ["BevelDifferentialGearSetCompoundPowerFlow"],
        "_4181": ["BevelDifferentialPlanetGearCompoundPowerFlow"],
        "_4182": ["BevelDifferentialSunGearCompoundPowerFlow"],
        "_4183": ["BevelGearCompoundPowerFlow"],
        "_4184": ["BevelGearMeshCompoundPowerFlow"],
        "_4185": ["BevelGearSetCompoundPowerFlow"],
        "_4186": ["BoltCompoundPowerFlow"],
        "_4187": ["BoltedJointCompoundPowerFlow"],
        "_4188": ["ClutchCompoundPowerFlow"],
        "_4189": ["ClutchConnectionCompoundPowerFlow"],
        "_4190": ["ClutchHalfCompoundPowerFlow"],
        "_4191": ["CoaxialConnectionCompoundPowerFlow"],
        "_4192": ["ComponentCompoundPowerFlow"],
        "_4193": ["ConceptCouplingCompoundPowerFlow"],
        "_4194": ["ConceptCouplingConnectionCompoundPowerFlow"],
        "_4195": ["ConceptCouplingHalfCompoundPowerFlow"],
        "_4196": ["ConceptGearCompoundPowerFlow"],
        "_4197": ["ConceptGearMeshCompoundPowerFlow"],
        "_4198": ["ConceptGearSetCompoundPowerFlow"],
        "_4199": ["ConicalGearCompoundPowerFlow"],
        "_4200": ["ConicalGearMeshCompoundPowerFlow"],
        "_4201": ["ConicalGearSetCompoundPowerFlow"],
        "_4202": ["ConnectionCompoundPowerFlow"],
        "_4203": ["ConnectorCompoundPowerFlow"],
        "_4204": ["CouplingCompoundPowerFlow"],
        "_4205": ["CouplingConnectionCompoundPowerFlow"],
        "_4206": ["CouplingHalfCompoundPowerFlow"],
        "_4207": ["CVTBeltConnectionCompoundPowerFlow"],
        "_4208": ["CVTCompoundPowerFlow"],
        "_4209": ["CVTPulleyCompoundPowerFlow"],
        "_4210": ["CycloidalAssemblyCompoundPowerFlow"],
        "_4211": ["CycloidalDiscCentralBearingConnectionCompoundPowerFlow"],
        "_4212": ["CycloidalDiscCompoundPowerFlow"],
        "_4213": ["CycloidalDiscPlanetaryBearingConnectionCompoundPowerFlow"],
        "_4214": ["CylindricalGearCompoundPowerFlow"],
        "_4215": ["CylindricalGearMeshCompoundPowerFlow"],
        "_4216": ["CylindricalGearSetCompoundPowerFlow"],
        "_4217": ["CylindricalPlanetGearCompoundPowerFlow"],
        "_4218": ["DatumCompoundPowerFlow"],
        "_4219": ["ExternalCADModelCompoundPowerFlow"],
        "_4220": ["FaceGearCompoundPowerFlow"],
        "_4221": ["FaceGearMeshCompoundPowerFlow"],
        "_4222": ["FaceGearSetCompoundPowerFlow"],
        "_4223": ["FEPartCompoundPowerFlow"],
        "_4224": ["FlexiblePinAssemblyCompoundPowerFlow"],
        "_4225": ["GearCompoundPowerFlow"],
        "_4226": ["GearMeshCompoundPowerFlow"],
        "_4227": ["GearSetCompoundPowerFlow"],
        "_4228": ["GuideDxfModelCompoundPowerFlow"],
        "_4229": ["HypoidGearCompoundPowerFlow"],
        "_4230": ["HypoidGearMeshCompoundPowerFlow"],
        "_4231": ["HypoidGearSetCompoundPowerFlow"],
        "_4232": ["InterMountableComponentConnectionCompoundPowerFlow"],
        "_4233": ["KlingelnbergCycloPalloidConicalGearCompoundPowerFlow"],
        "_4234": ["KlingelnbergCycloPalloidConicalGearMeshCompoundPowerFlow"],
        "_4235": ["KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow"],
        "_4236": ["KlingelnbergCycloPalloidHypoidGearCompoundPowerFlow"],
        "_4237": ["KlingelnbergCycloPalloidHypoidGearMeshCompoundPowerFlow"],
        "_4238": ["KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow"],
        "_4239": ["KlingelnbergCycloPalloidSpiralBevelGearCompoundPowerFlow"],
        "_4240": ["KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundPowerFlow"],
        "_4241": ["KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow"],
        "_4242": ["MassDiscCompoundPowerFlow"],
        "_4243": ["MeasurementComponentCompoundPowerFlow"],
        "_4244": ["MountableComponentCompoundPowerFlow"],
        "_4245": ["OilSealCompoundPowerFlow"],
        "_4246": ["PartCompoundPowerFlow"],
        "_4247": ["PartToPartShearCouplingCompoundPowerFlow"],
        "_4248": ["PartToPartShearCouplingConnectionCompoundPowerFlow"],
        "_4249": ["PartToPartShearCouplingHalfCompoundPowerFlow"],
        "_4250": ["PlanetaryConnectionCompoundPowerFlow"],
        "_4251": ["PlanetaryGearSetCompoundPowerFlow"],
        "_4252": ["PlanetCarrierCompoundPowerFlow"],
        "_4253": ["PointLoadCompoundPowerFlow"],
        "_4254": ["PowerLoadCompoundPowerFlow"],
        "_4255": ["PulleyCompoundPowerFlow"],
        "_4256": ["RingPinsCompoundPowerFlow"],
        "_4257": ["RingPinsToDiscConnectionCompoundPowerFlow"],
        "_4258": ["RollingRingAssemblyCompoundPowerFlow"],
        "_4259": ["RollingRingCompoundPowerFlow"],
        "_4260": ["RollingRingConnectionCompoundPowerFlow"],
        "_4261": ["RootAssemblyCompoundPowerFlow"],
        "_4262": ["ShaftCompoundPowerFlow"],
        "_4263": ["ShaftHubConnectionCompoundPowerFlow"],
        "_4264": ["ShaftToMountableComponentConnectionCompoundPowerFlow"],
        "_4265": ["SpecialisedAssemblyCompoundPowerFlow"],
        "_4266": ["SpiralBevelGearCompoundPowerFlow"],
        "_4267": ["SpiralBevelGearMeshCompoundPowerFlow"],
        "_4268": ["SpiralBevelGearSetCompoundPowerFlow"],
        "_4269": ["SpringDamperCompoundPowerFlow"],
        "_4270": ["SpringDamperConnectionCompoundPowerFlow"],
        "_4271": ["SpringDamperHalfCompoundPowerFlow"],
        "_4272": ["StraightBevelDiffGearCompoundPowerFlow"],
        "_4273": ["StraightBevelDiffGearMeshCompoundPowerFlow"],
        "_4274": ["StraightBevelDiffGearSetCompoundPowerFlow"],
        "_4275": ["StraightBevelGearCompoundPowerFlow"],
        "_4276": ["StraightBevelGearMeshCompoundPowerFlow"],
        "_4277": ["StraightBevelGearSetCompoundPowerFlow"],
        "_4278": ["StraightBevelPlanetGearCompoundPowerFlow"],
        "_4279": ["StraightBevelSunGearCompoundPowerFlow"],
        "_4280": ["SynchroniserCompoundPowerFlow"],
        "_4281": ["SynchroniserHalfCompoundPowerFlow"],
        "_4282": ["SynchroniserPartCompoundPowerFlow"],
        "_4283": ["SynchroniserSleeveCompoundPowerFlow"],
        "_4284": ["TorqueConverterCompoundPowerFlow"],
        "_4285": ["TorqueConverterConnectionCompoundPowerFlow"],
        "_4286": ["TorqueConverterPumpCompoundPowerFlow"],
        "_4287": ["TorqueConverterTurbineCompoundPowerFlow"],
        "_4288": ["UnbalancedMassCompoundPowerFlow"],
        "_4289": ["VirtualComponentCompoundPowerFlow"],
        "_4290": ["WormGearCompoundPowerFlow"],
        "_4291": ["WormGearMeshCompoundPowerFlow"],
        "_4292": ["WormGearSetCompoundPowerFlow"],
        "_4293": ["ZerolBevelGearCompoundPowerFlow"],
        "_4294": ["ZerolBevelGearMeshCompoundPowerFlow"],
        "_4295": ["ZerolBevelGearSetCompoundPowerFlow"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundPowerFlow",
    "AbstractShaftCompoundPowerFlow",
    "AbstractShaftOrHousingCompoundPowerFlow",
    "AbstractShaftToMountableComponentConnectionCompoundPowerFlow",
    "AGMAGleasonConicalGearCompoundPowerFlow",
    "AGMAGleasonConicalGearMeshCompoundPowerFlow",
    "AGMAGleasonConicalGearSetCompoundPowerFlow",
    "AssemblyCompoundPowerFlow",
    "BearingCompoundPowerFlow",
    "BeltConnectionCompoundPowerFlow",
    "BeltDriveCompoundPowerFlow",
    "BevelDifferentialGearCompoundPowerFlow",
    "BevelDifferentialGearMeshCompoundPowerFlow",
    "BevelDifferentialGearSetCompoundPowerFlow",
    "BevelDifferentialPlanetGearCompoundPowerFlow",
    "BevelDifferentialSunGearCompoundPowerFlow",
    "BevelGearCompoundPowerFlow",
    "BevelGearMeshCompoundPowerFlow",
    "BevelGearSetCompoundPowerFlow",
    "BoltCompoundPowerFlow",
    "BoltedJointCompoundPowerFlow",
    "ClutchCompoundPowerFlow",
    "ClutchConnectionCompoundPowerFlow",
    "ClutchHalfCompoundPowerFlow",
    "CoaxialConnectionCompoundPowerFlow",
    "ComponentCompoundPowerFlow",
    "ConceptCouplingCompoundPowerFlow",
    "ConceptCouplingConnectionCompoundPowerFlow",
    "ConceptCouplingHalfCompoundPowerFlow",
    "ConceptGearCompoundPowerFlow",
    "ConceptGearMeshCompoundPowerFlow",
    "ConceptGearSetCompoundPowerFlow",
    "ConicalGearCompoundPowerFlow",
    "ConicalGearMeshCompoundPowerFlow",
    "ConicalGearSetCompoundPowerFlow",
    "ConnectionCompoundPowerFlow",
    "ConnectorCompoundPowerFlow",
    "CouplingCompoundPowerFlow",
    "CouplingConnectionCompoundPowerFlow",
    "CouplingHalfCompoundPowerFlow",
    "CVTBeltConnectionCompoundPowerFlow",
    "CVTCompoundPowerFlow",
    "CVTPulleyCompoundPowerFlow",
    "CycloidalAssemblyCompoundPowerFlow",
    "CycloidalDiscCentralBearingConnectionCompoundPowerFlow",
    "CycloidalDiscCompoundPowerFlow",
    "CycloidalDiscPlanetaryBearingConnectionCompoundPowerFlow",
    "CylindricalGearCompoundPowerFlow",
    "CylindricalGearMeshCompoundPowerFlow",
    "CylindricalGearSetCompoundPowerFlow",
    "CylindricalPlanetGearCompoundPowerFlow",
    "DatumCompoundPowerFlow",
    "ExternalCADModelCompoundPowerFlow",
    "FaceGearCompoundPowerFlow",
    "FaceGearMeshCompoundPowerFlow",
    "FaceGearSetCompoundPowerFlow",
    "FEPartCompoundPowerFlow",
    "FlexiblePinAssemblyCompoundPowerFlow",
    "GearCompoundPowerFlow",
    "GearMeshCompoundPowerFlow",
    "GearSetCompoundPowerFlow",
    "GuideDxfModelCompoundPowerFlow",
    "HypoidGearCompoundPowerFlow",
    "HypoidGearMeshCompoundPowerFlow",
    "HypoidGearSetCompoundPowerFlow",
    "InterMountableComponentConnectionCompoundPowerFlow",
    "KlingelnbergCycloPalloidConicalGearCompoundPowerFlow",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundPowerFlow",
    "KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow",
    "KlingelnbergCycloPalloidHypoidGearCompoundPowerFlow",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundPowerFlow",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundPowerFlow",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundPowerFlow",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow",
    "MassDiscCompoundPowerFlow",
    "MeasurementComponentCompoundPowerFlow",
    "MountableComponentCompoundPowerFlow",
    "OilSealCompoundPowerFlow",
    "PartCompoundPowerFlow",
    "PartToPartShearCouplingCompoundPowerFlow",
    "PartToPartShearCouplingConnectionCompoundPowerFlow",
    "PartToPartShearCouplingHalfCompoundPowerFlow",
    "PlanetaryConnectionCompoundPowerFlow",
    "PlanetaryGearSetCompoundPowerFlow",
    "PlanetCarrierCompoundPowerFlow",
    "PointLoadCompoundPowerFlow",
    "PowerLoadCompoundPowerFlow",
    "PulleyCompoundPowerFlow",
    "RingPinsCompoundPowerFlow",
    "RingPinsToDiscConnectionCompoundPowerFlow",
    "RollingRingAssemblyCompoundPowerFlow",
    "RollingRingCompoundPowerFlow",
    "RollingRingConnectionCompoundPowerFlow",
    "RootAssemblyCompoundPowerFlow",
    "ShaftCompoundPowerFlow",
    "ShaftHubConnectionCompoundPowerFlow",
    "ShaftToMountableComponentConnectionCompoundPowerFlow",
    "SpecialisedAssemblyCompoundPowerFlow",
    "SpiralBevelGearCompoundPowerFlow",
    "SpiralBevelGearMeshCompoundPowerFlow",
    "SpiralBevelGearSetCompoundPowerFlow",
    "SpringDamperCompoundPowerFlow",
    "SpringDamperConnectionCompoundPowerFlow",
    "SpringDamperHalfCompoundPowerFlow",
    "StraightBevelDiffGearCompoundPowerFlow",
    "StraightBevelDiffGearMeshCompoundPowerFlow",
    "StraightBevelDiffGearSetCompoundPowerFlow",
    "StraightBevelGearCompoundPowerFlow",
    "StraightBevelGearMeshCompoundPowerFlow",
    "StraightBevelGearSetCompoundPowerFlow",
    "StraightBevelPlanetGearCompoundPowerFlow",
    "StraightBevelSunGearCompoundPowerFlow",
    "SynchroniserCompoundPowerFlow",
    "SynchroniserHalfCompoundPowerFlow",
    "SynchroniserPartCompoundPowerFlow",
    "SynchroniserSleeveCompoundPowerFlow",
    "TorqueConverterCompoundPowerFlow",
    "TorqueConverterConnectionCompoundPowerFlow",
    "TorqueConverterPumpCompoundPowerFlow",
    "TorqueConverterTurbineCompoundPowerFlow",
    "UnbalancedMassCompoundPowerFlow",
    "VirtualComponentCompoundPowerFlow",
    "WormGearCompoundPowerFlow",
    "WormGearMeshCompoundPowerFlow",
    "WormGearSetCompoundPowerFlow",
    "ZerolBevelGearCompoundPowerFlow",
    "ZerolBevelGearMeshCompoundPowerFlow",
    "ZerolBevelGearSetCompoundPowerFlow",
)



"""ISO6336MetalRateableMesh"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy.gears.rating.cylindrical.iso6336 import _523
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ISO6336_METAL_RATEABLE_MESH = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Cylindrical.ISO6336", "ISO6336MetalRateableMesh"
)

if TYPE_CHECKING:
    from mastapy.gears.rating.cylindrical import _471
    from mastapy.gears.rating import _367


__docformat__ = "restructuredtext en"
__all__ = ("ISO6336MetalRateableMesh",)


Self = TypeVar("Self", bound="ISO6336MetalRateableMesh")


class ISO6336MetalRateableMesh(_523.ISO6336RateableMesh):
    """ISO6336MetalRateableMesh

    This is a mastapy class.
    """

    TYPE = _ISO6336_METAL_RATEABLE_MESH
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_ISO6336MetalRateableMesh")

    class _Cast_ISO6336MetalRateableMesh:
        """Special nested class for casting ISO6336MetalRateableMesh to subclasses."""

        def __init__(
            self: "ISO6336MetalRateableMesh._Cast_ISO6336MetalRateableMesh",
            parent: "ISO6336MetalRateableMesh",
        ):
            self._parent = parent

        @property
        def iso6336_rateable_mesh(
            self: "ISO6336MetalRateableMesh._Cast_ISO6336MetalRateableMesh",
        ) -> "_523.ISO6336RateableMesh":
            return self._parent._cast(_523.ISO6336RateableMesh)

        @property
        def cylindrical_rateable_mesh(
            self: "ISO6336MetalRateableMesh._Cast_ISO6336MetalRateableMesh",
        ) -> "_471.CylindricalRateableMesh":
            from mastapy.gears.rating.cylindrical import _471

            return self._parent._cast(_471.CylindricalRateableMesh)

        @property
        def rateable_mesh(
            self: "ISO6336MetalRateableMesh._Cast_ISO6336MetalRateableMesh",
        ) -> "_367.RateableMesh":
            from mastapy.gears.rating import _367

            return self._parent._cast(_367.RateableMesh)

        @property
        def iso6336_metal_rateable_mesh(
            self: "ISO6336MetalRateableMesh._Cast_ISO6336MetalRateableMesh",
        ) -> "ISO6336MetalRateableMesh":
            return self._parent

        def __getattr__(
            self: "ISO6336MetalRateableMesh._Cast_ISO6336MetalRateableMesh", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "ISO6336MetalRateableMesh.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cast_to(
        self: Self,
    ) -> "ISO6336MetalRateableMesh._Cast_ISO6336MetalRateableMesh":
        return self._Cast_ISO6336MetalRateableMesh(self)



"""LoadedRollerElementChartReporter"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy.utility.report import _1756
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_LOADED_ROLLER_ELEMENT_CHART_REPORTER = python_net_import(
    "SMT.MastaAPI.Bearings.BearingResults", "LoadedRollerElementChartReporter"
)

if TYPE_CHECKING:
    from mastapy.utility.report import _1769, _1770, _1771, _1763


__docformat__ = "restructuredtext en"
__all__ = ("LoadedRollerElementChartReporter",)


Self = TypeVar("Self", bound="LoadedRollerElementChartReporter")


class LoadedRollerElementChartReporter(_1756.CustomReportChart):
    """LoadedRollerElementChartReporter

    This is a mastapy class.
    """

    TYPE = _LOADED_ROLLER_ELEMENT_CHART_REPORTER
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_LoadedRollerElementChartReporter")

    class _Cast_LoadedRollerElementChartReporter:
        """Special nested class for casting LoadedRollerElementChartReporter to subclasses."""

        def __init__(
            self: "LoadedRollerElementChartReporter._Cast_LoadedRollerElementChartReporter",
            parent: "LoadedRollerElementChartReporter",
        ):
            self._parent = parent

        @property
        def custom_report_chart(
            self: "LoadedRollerElementChartReporter._Cast_LoadedRollerElementChartReporter",
        ) -> "_1756.CustomReportChart":
            return self._parent._cast(_1756.CustomReportChart)

        @property
        def custom_report_multi_property_item(
            self: "LoadedRollerElementChartReporter._Cast_LoadedRollerElementChartReporter",
        ) -> "_1769.CustomReportMultiPropertyItem":
            pass

            from mastapy.utility.report import _1769

            return self._parent._cast(_1769.CustomReportMultiPropertyItem)

        @property
        def custom_report_multi_property_item_base(
            self: "LoadedRollerElementChartReporter._Cast_LoadedRollerElementChartReporter",
        ) -> "_1770.CustomReportMultiPropertyItemBase":
            from mastapy.utility.report import _1770

            return self._parent._cast(_1770.CustomReportMultiPropertyItemBase)

        @property
        def custom_report_nameable_item(
            self: "LoadedRollerElementChartReporter._Cast_LoadedRollerElementChartReporter",
        ) -> "_1771.CustomReportNameableItem":
            from mastapy.utility.report import _1771

            return self._parent._cast(_1771.CustomReportNameableItem)

        @property
        def custom_report_item(
            self: "LoadedRollerElementChartReporter._Cast_LoadedRollerElementChartReporter",
        ) -> "_1763.CustomReportItem":
            from mastapy.utility.report import _1763

            return self._parent._cast(_1763.CustomReportItem)

        @property
        def loaded_roller_element_chart_reporter(
            self: "LoadedRollerElementChartReporter._Cast_LoadedRollerElementChartReporter",
        ) -> "LoadedRollerElementChartReporter":
            return self._parent

        def __getattr__(
            self: "LoadedRollerElementChartReporter._Cast_LoadedRollerElementChartReporter",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "LoadedRollerElementChartReporter.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def only_show_roller_with_highest_load(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.OnlyShowRollerWithHighestLoad

        if temp is None:
            return False

        return temp

    @only_show_roller_with_highest_load.setter
    @enforce_parameter_types
    def only_show_roller_with_highest_load(self: Self, value: "bool"):
        self.wrapped.OnlyShowRollerWithHighestLoad = (
            bool(value) if value is not None else False
        )

    @property
    def start_y_axis_at_zero(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.StartYAxisAtZero

        if temp is None:
            return False

        return temp

    @start_y_axis_at_zero.setter
    @enforce_parameter_types
    def start_y_axis_at_zero(self: Self, value: "bool"):
        self.wrapped.StartYAxisAtZero = bool(value) if value is not None else False

    @property
    def cast_to(
        self: Self,
    ) -> "LoadedRollerElementChartReporter._Cast_LoadedRollerElementChartReporter":
        return self._Cast_LoadedRollerElementChartReporter(self)



"""CustomRow"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy.utility.report import _1773
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_CUSTOM_ROW = python_net_import("SMT.MastaAPI.Utility.Report", "CustomRow")

if TYPE_CHECKING:
    from mastapy.utility.report import _1744, _1787


__docformat__ = "restructuredtext en"
__all__ = ("CustomRow",)


Self = TypeVar("Self", bound="CustomRow")


class CustomRow(_1773.CustomReportPropertyItem):
    """CustomRow

    This is a mastapy class.
    """

    TYPE = _CUSTOM_ROW
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_CustomRow")

    class _Cast_CustomRow:
        """Special nested class for casting CustomRow to subclasses."""

        def __init__(self: "CustomRow._Cast_CustomRow", parent: "CustomRow"):
            self._parent = parent

        @property
        def custom_report_property_item(
            self: "CustomRow._Cast_CustomRow",
        ) -> "_1773.CustomReportPropertyItem":
            return self._parent._cast(_1773.CustomReportPropertyItem)

        @property
        def blank_row(self: "CustomRow._Cast_CustomRow") -> "_1744.BlankRow":
            from mastapy.utility.report import _1744

            return self._parent._cast(_1744.BlankRow)

        @property
        def user_text_row(self: "CustomRow._Cast_CustomRow") -> "_1787.UserTextRow":
            from mastapy.utility.report import _1787

            return self._parent._cast(_1787.UserTextRow)

        @property
        def custom_row(self: "CustomRow._Cast_CustomRow") -> "CustomRow":
            return self._parent

        def __getattr__(self: "CustomRow._Cast_CustomRow", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "CustomRow.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def calculate_sum_of_values(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.CalculateSumOfValues

        if temp is None:
            return False

        return temp

    @calculate_sum_of_values.setter
    @enforce_parameter_types
    def calculate_sum_of_values(self: Self, value: "bool"):
        self.wrapped.CalculateSumOfValues = bool(value) if value is not None else False

    @property
    def count_values(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.CountValues

        if temp is None:
            return False

        return temp

    @count_values.setter
    @enforce_parameter_types
    def count_values(self: Self, value: "bool"):
        self.wrapped.CountValues = bool(value) if value is not None else False

    @property
    def is_minor_value(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.IsMinorValue

        if temp is None:
            return False

        return temp

    @is_minor_value.setter
    @enforce_parameter_types
    def is_minor_value(self: Self, value: "bool"):
        self.wrapped.IsMinorValue = bool(value) if value is not None else False

    @property
    def overridden_property_name(self: Self) -> "str":
        """str"""
        temp = self.wrapped.OverriddenPropertyName

        if temp is None:
            return ""

        return temp

    @overridden_property_name.setter
    @enforce_parameter_types
    def overridden_property_name(self: Self, value: "str"):
        self.wrapped.OverriddenPropertyName = str(value) if value is not None else ""

    @property
    def override_property_name(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.OverridePropertyName

        if temp is None:
            return False

        return temp

    @override_property_name.setter
    @enforce_parameter_types
    def override_property_name(self: Self, value: "bool"):
        self.wrapped.OverridePropertyName = bool(value) if value is not None else False

    @property
    def show_maximum_of_absolute_values(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.ShowMaximumOfAbsoluteValues

        if temp is None:
            return False

        return temp

    @show_maximum_of_absolute_values.setter
    @enforce_parameter_types
    def show_maximum_of_absolute_values(self: Self, value: "bool"):
        self.wrapped.ShowMaximumOfAbsoluteValues = (
            bool(value) if value is not None else False
        )

    @property
    def show_maximum_of_values(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.ShowMaximumOfValues

        if temp is None:
            return False

        return temp

    @show_maximum_of_values.setter
    @enforce_parameter_types
    def show_maximum_of_values(self: Self, value: "bool"):
        self.wrapped.ShowMaximumOfValues = bool(value) if value is not None else False

    @property
    def show_minimum_of_values(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.ShowMinimumOfValues

        if temp is None:
            return False

        return temp

    @show_minimum_of_values.setter
    @enforce_parameter_types
    def show_minimum_of_values(self: Self, value: "bool"):
        self.wrapped.ShowMinimumOfValues = bool(value) if value is not None else False

    @property
    def cast_to(self: Self) -> "CustomRow._Cast_CustomRow":
        return self._Cast_CustomRow(self)



"""HarmonicAnalysisOptions"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, Union, Tuple, List

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_HARMONIC_ANALYSIS_OPTIONS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses",
    "HarmonicAnalysisOptions",
)

if TYPE_CHECKING:
    from mastapy.system_model.analyses_and_results.harmonic_analyses import (
        _5799,
        _5752,
        _5811,
        _5818,
    )
    from mastapy.system_model.analyses_and_results.harmonic_analyses.results import (
        _5847,
    )
    from mastapy.system_model.analyses_and_results.modal_analyses import _4657
    from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
        _7073,
    )


__docformat__ = "restructuredtext en"
__all__ = ("HarmonicAnalysisOptions",)


Self = TypeVar("Self", bound="HarmonicAnalysisOptions")


class HarmonicAnalysisOptions(_0.APIBase):
    """HarmonicAnalysisOptions

    This is a mastapy class.
    """

    TYPE = _HARMONIC_ANALYSIS_OPTIONS
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_HarmonicAnalysisOptions")

    class _Cast_HarmonicAnalysisOptions:
        """Special nested class for casting HarmonicAnalysisOptions to subclasses."""

        def __init__(
            self: "HarmonicAnalysisOptions._Cast_HarmonicAnalysisOptions",
            parent: "HarmonicAnalysisOptions",
        ):
            self._parent = parent

        @property
        def harmonic_analysis_options_for_advanced_time_stepping_analysis_for_modulation(
            self: "HarmonicAnalysisOptions._Cast_HarmonicAnalysisOptions",
        ) -> (
            "_7073.HarmonicAnalysisOptionsForAdvancedTimeSteppingAnalysisForModulation"
        ):
            from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
                _7073,
            )

            return self._parent._cast(
                _7073.HarmonicAnalysisOptionsForAdvancedTimeSteppingAnalysisForModulation
            )

        @property
        def harmonic_analysis_options(
            self: "HarmonicAnalysisOptions._Cast_HarmonicAnalysisOptions",
        ) -> "HarmonicAnalysisOptions":
            return self._parent

        def __getattr__(
            self: "HarmonicAnalysisOptions._Cast_HarmonicAnalysisOptions", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "HarmonicAnalysisOptions.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def amplitude_cut_off_for_linear_te(self: Self) -> "float":
        """float"""
        temp = self.wrapped.AmplitudeCutOffForLinearTE

        if temp is None:
            return 0.0

        return temp

    @amplitude_cut_off_for_linear_te.setter
    @enforce_parameter_types
    def amplitude_cut_off_for_linear_te(self: Self, value: "float"):
        self.wrapped.AmplitudeCutOffForLinearTE = (
            float(value) if value is not None else 0.0
        )

    @property
    def amplitude_cut_off_for_misalignment_excitation(self: Self) -> "float":
        """float"""
        temp = self.wrapped.AmplitudeCutOffForMisalignmentExcitation

        if temp is None:
            return 0.0

        return temp

    @amplitude_cut_off_for_misalignment_excitation.setter
    @enforce_parameter_types
    def amplitude_cut_off_for_misalignment_excitation(self: Self, value: "float"):
        self.wrapped.AmplitudeCutOffForMisalignmentExcitation = (
            float(value) if value is not None else 0.0
        )

    @property
    def calculate_uncoupled_modes_during_analysis(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.CalculateUncoupledModesDuringAnalysis

        if temp is None:
            return False

        return temp

    @calculate_uncoupled_modes_during_analysis.setter
    @enforce_parameter_types
    def calculate_uncoupled_modes_during_analysis(self: Self, value: "bool"):
        self.wrapped.CalculateUncoupledModesDuringAnalysis = (
            bool(value) if value is not None else False
        )

    @property
    def crop_to_speed_range_for_export_and_reports(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.CropToSpeedRangeForExportAndReports

        if temp is None:
            return False

        return temp

    @crop_to_speed_range_for_export_and_reports.setter
    @enforce_parameter_types
    def crop_to_speed_range_for_export_and_reports(self: Self, value: "bool"):
        self.wrapped.CropToSpeedRangeForExportAndReports = (
            bool(value) if value is not None else False
        )

    @property
    def modal_damping_factor(self: Self) -> "float":
        """float"""
        temp = self.wrapped.ModalDampingFactor

        if temp is None:
            return 0.0

        return temp

    @modal_damping_factor.setter
    @enforce_parameter_types
    def modal_damping_factor(self: Self, value: "float"):
        self.wrapped.ModalDampingFactor = float(value) if value is not None else 0.0

    @property
    def number_of_harmonics(self: Self) -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = self.wrapped.NumberOfHarmonics

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @number_of_harmonics.setter
    @enforce_parameter_types
    def number_of_harmonics(self: Self, value: "Union[int, Tuple[int, bool]]"):
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        self.wrapped.NumberOfHarmonics = value

    @property
    def penalty_mass_for_enforced_te(self: Self) -> "float":
        """float"""
        temp = self.wrapped.PenaltyMassForEnforcedTE

        if temp is None:
            return 0.0

        return temp

    @penalty_mass_for_enforced_te.setter
    @enforce_parameter_types
    def penalty_mass_for_enforced_te(self: Self, value: "float"):
        self.wrapped.PenaltyMassForEnforcedTE = (
            float(value) if value is not None else 0.0
        )

    @property
    def penalty_stiffness_for_enforced_te(self: Self) -> "float":
        """float"""
        temp = self.wrapped.PenaltyStiffnessForEnforcedTE

        if temp is None:
            return 0.0

        return temp

    @penalty_stiffness_for_enforced_te.setter
    @enforce_parameter_types
    def penalty_stiffness_for_enforced_te(self: Self, value: "float"):
        self.wrapped.PenaltyStiffnessForEnforcedTE = (
            float(value) if value is not None else 0.0
        )

    @property
    def rayleigh_damping_alpha(self: Self) -> "float":
        """float"""
        temp = self.wrapped.RayleighDampingAlpha

        if temp is None:
            return 0.0

        return temp

    @rayleigh_damping_alpha.setter
    @enforce_parameter_types
    def rayleigh_damping_alpha(self: Self, value: "float"):
        self.wrapped.RayleighDampingAlpha = float(value) if value is not None else 0.0

    @property
    def rayleigh_damping_beta(self: Self) -> "float":
        """float"""
        temp = self.wrapped.RayleighDampingBeta

        if temp is None:
            return 0.0

        return temp

    @rayleigh_damping_beta.setter
    @enforce_parameter_types
    def rayleigh_damping_beta(self: Self, value: "float"):
        self.wrapped.RayleighDampingBeta = float(value) if value is not None else 0.0

    @property
    def response_cache_level(self: Self) -> "_5799.ResponseCacheLevel":
        """mastapy.system_model.analyses_and_results.harmonic_analyses.ResponseCacheLevel"""
        temp = self.wrapped.ResponseCacheLevel

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses.ResponseCacheLevel",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.system_model.analyses_and_results.harmonic_analyses._5799",
            "ResponseCacheLevel",
        )(value)

    @response_cache_level.setter
    @enforce_parameter_types
    def response_cache_level(self: Self, value: "_5799.ResponseCacheLevel"):
        value = conversion.mp_to_pn_enum(
            value,
            "SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses.ResponseCacheLevel",
        )
        self.wrapped.ResponseCacheLevel = value

    @property
    def specify_per_mode_damping_factors(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.SpecifyPerModeDampingFactors

        if temp is None:
            return False

        return temp

    @specify_per_mode_damping_factors.setter
    @enforce_parameter_types
    def specify_per_mode_damping_factors(self: Self, value: "bool"):
        self.wrapped.SpecifyPerModeDampingFactors = (
            bool(value) if value is not None else False
        )

    @property
    def update_dynamic_response_chart_on_change_of_settings(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.UpdateDynamicResponseChartOnChangeOfSettings

        if temp is None:
            return False

        return temp

    @update_dynamic_response_chart_on_change_of_settings.setter
    @enforce_parameter_types
    def update_dynamic_response_chart_on_change_of_settings(self: Self, value: "bool"):
        self.wrapped.UpdateDynamicResponseChartOnChangeOfSettings = (
            bool(value) if value is not None else False
        )

    @property
    def excitation_selection(self: Self) -> "_5847.ExcitationSourceSelectionGroup":
        """mastapy.system_model.analyses_and_results.harmonic_analyses.results.ExcitationSourceSelectionGroup

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ExcitationSelection

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def frequency_options(
        self: Self,
    ) -> "_5752.FrequencyOptionsForHarmonicAnalysisResults":
        """mastapy.system_model.analyses_and_results.harmonic_analyses.FrequencyOptionsForHarmonicAnalysisResults

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FrequencyOptions

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def modal_analysis_options(self: Self) -> "_4657.ModalAnalysisOptions":
        """mastapy.system_model.analyses_and_results.modal_analyses.ModalAnalysisOptions

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ModalAnalysisOptions

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def reference_speed_options(
        self: Self,
    ) -> "_5811.SpeedOptionsForHarmonicAnalysisResults":
        """mastapy.system_model.analyses_and_results.harmonic_analyses.SpeedOptionsForHarmonicAnalysisResults

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReferenceSpeedOptions

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def stiffness_options(self: Self) -> "_5818.StiffnessOptionsForHarmonicAnalysis":
        """mastapy.system_model.analyses_and_results.harmonic_analyses.StiffnessOptionsForHarmonicAnalysis

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StiffnessOptions

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def per_mode_damping_factors(self: Self) -> "List[float]":
        """List[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PerModeDampingFactors

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, float)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def set_per_mode_damping_factor(self: Self, mode: "int", damping: "float"):
        """Method does not return.

        Args:
            mode (int)
            damping (float)
        """
        mode = int(mode)
        damping = float(damping)
        self.wrapped.SetPerModeDampingFactor(
            mode if mode else 0, damping if damping else 0.0
        )

    @enforce_parameter_types
    def set_per_mode_damping_factors(self: Self, damping_values: "List[float]"):
        """Method does not return.

        Args:
            damping_values (List[float])
        """
        damping_values = conversion.mp_to_pn_list_float(damping_values)
        self.wrapped.SetPerModeDampingFactors(damping_values)

    @property
    def cast_to(self: Self) -> "HarmonicAnalysisOptions._Cast_HarmonicAnalysisOptions":
        return self._Cast_HarmonicAnalysisOptions(self)



"""ActiveProfileRangeCalculationSource"""

from __future__ import annotations

from typing import TypeVar, Any
from enum import Enum

from mastapy._internal.python_net import python_net_import

_ACTIVE_PROFILE_RANGE_CALCULATION_SOURCE = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.AxialAndPlungeShavingDynamics",
    "ActiveProfileRangeCalculationSource",
)


__docformat__ = "restructuredtext en"
__all__ = ("ActiveProfileRangeCalculationSource",)


Self = TypeVar("Self", bound="ActiveProfileRangeCalculationSource")


class ActiveProfileRangeCalculationSource(Enum):
    """ActiveProfileRangeCalculationSource

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls):
        return _ACTIVE_PROFILE_RANGE_CALCULATION_SOURCE

    DESIGNED_GEAR_WITHOUT_TOLERANCES = 0
    MANUFACTURED_GEAR_WITH_TOLERANCES = 1


def __enum_setattr(self: Self, attr: str, value: Any):
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: Self, attr: str):
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


ActiveProfileRangeCalculationSource.__setattr__ = __enum_setattr
ActiveProfileRangeCalculationSource.__delattr__ = __enum_delattr



"""InterferenceFitHalfDesign"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, Union, Tuple

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy.detailed_rigid_connectors import _1387
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_INTERFERENCE_FIT_HALF_DESIGN = python_net_import(
    "SMT.MastaAPI.DetailedRigidConnectors.InterferenceFits", "InterferenceFitHalfDesign"
)

if TYPE_CHECKING:
    from mastapy.detailed_rigid_connectors.interference_fits import _1446
    from mastapy.bearings.tolerances import _1922
    from mastapy.detailed_rigid_connectors.keyed_joints import _1438


__docformat__ = "restructuredtext en"
__all__ = ("InterferenceFitHalfDesign",)


Self = TypeVar("Self", bound="InterferenceFitHalfDesign")


class InterferenceFitHalfDesign(_1387.DetailedRigidConnectorHalfDesign):
    """InterferenceFitHalfDesign

    This is a mastapy class.
    """

    TYPE = _INTERFERENCE_FIT_HALF_DESIGN
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_InterferenceFitHalfDesign")

    class _Cast_InterferenceFitHalfDesign:
        """Special nested class for casting InterferenceFitHalfDesign to subclasses."""

        def __init__(
            self: "InterferenceFitHalfDesign._Cast_InterferenceFitHalfDesign",
            parent: "InterferenceFitHalfDesign",
        ):
            self._parent = parent

        @property
        def detailed_rigid_connector_half_design(
            self: "InterferenceFitHalfDesign._Cast_InterferenceFitHalfDesign",
        ) -> "_1387.DetailedRigidConnectorHalfDesign":
            return self._parent._cast(_1387.DetailedRigidConnectorHalfDesign)

        @property
        def keyway_joint_half_design(
            self: "InterferenceFitHalfDesign._Cast_InterferenceFitHalfDesign",
        ) -> "_1438.KeywayJointHalfDesign":
            from mastapy.detailed_rigid_connectors.keyed_joints import _1438

            return self._parent._cast(_1438.KeywayJointHalfDesign)

        @property
        def interference_fit_half_design(
            self: "InterferenceFitHalfDesign._Cast_InterferenceFitHalfDesign",
        ) -> "InterferenceFitHalfDesign":
            return self._parent

        def __getattr__(
            self: "InterferenceFitHalfDesign._Cast_InterferenceFitHalfDesign", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "InterferenceFitHalfDesign.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def average_joint_diameter(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AverageJointDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def average_surface_roughness(self: Self) -> "float":
        """float"""
        temp = self.wrapped.AverageSurfaceRoughness

        if temp is None:
            return 0.0

        return temp

    @average_surface_roughness.setter
    @enforce_parameter_types
    def average_surface_roughness(self: Self, value: "float"):
        self.wrapped.AverageSurfaceRoughness = (
            float(value) if value is not None else 0.0
        )

    @property
    def designation(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Designation

        if temp is None:
            return ""

        return temp

    @property
    def diameter_ratio(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DiameterRatio

        if temp is None:
            return 0.0

        return temp

    @property
    def joint_pressure_for_fully_plastic_part(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.JointPressureForFullyPlasticPart

        if temp is None:
            return 0.0

        return temp

    @property
    def lower_deviation(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LowerDeviation

        if temp is None:
            return 0.0

        return temp

    @property
    def name(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Name

        if temp is None:
            return ""

        return temp

    @property
    def nominal_joint_diameter(self: Self) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.NominalJointDiameter

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @nominal_joint_diameter.setter
    @enforce_parameter_types
    def nominal_joint_diameter(self: Self, value: "Union[float, Tuple[float, bool]]"):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.NominalJointDiameter = value

    @property
    def permissible_joint_pressure_for_fully_elastic_part(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PermissibleJointPressureForFullyElasticPart

        if temp is None:
            return 0.0

        return temp

    @property
    def permissible_relative_interference_for_fully_elastic_part(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PermissibleRelativeInterferenceForFullyElasticPart

        if temp is None:
            return 0.0

        return temp

    @property
    def required_safety_against_plastic_strain(
        self: Self,
    ) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.RequiredSafetyAgainstPlasticStrain

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @required_safety_against_plastic_strain.setter
    @enforce_parameter_types
    def required_safety_against_plastic_strain(
        self: Self, value: "Union[float, Tuple[float, bool]]"
    ):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.RequiredSafetyAgainstPlasticStrain = value

    @property
    def stress_region(self: Self) -> "_1446.StressRegions":
        """mastapy.detailed_rigid_connectors.interference_fits.StressRegions

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StressRegion

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.DetailedRigidConnectors.InterferenceFits.StressRegions"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.detailed_rigid_connectors.interference_fits._1446", "StressRegions"
        )(value)

    @property
    def upper_deviation(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.UpperDeviation

        if temp is None:
            return 0.0

        return temp

    @property
    def tolerance(self: Self) -> "_1922.SupportTolerance":
        """mastapy.bearings.tolerances.SupportTolerance

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Tolerance

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "InterferenceFitHalfDesign._Cast_InterferenceFitHalfDesign":
        return self._Cast_InterferenceFitHalfDesign(self)



"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._1234 import BeamSectionType
    from ._1235 import ContactPairConstrainedSurfaceType
    from ._1236 import ContactPairReferenceSurfaceType
    from ._1237 import ElementPropertiesShellWallType
else:
    import_structure = {
        "_1234": ["BeamSectionType"],
        "_1235": ["ContactPairConstrainedSurfaceType"],
        "_1236": ["ContactPairReferenceSurfaceType"],
        "_1237": ["ElementPropertiesShellWallType"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "BeamSectionType",
    "ContactPairConstrainedSurfaceType",
    "ContactPairReferenceSurfaceType",
    "ElementPropertiesShellWallType",
)



"""StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
    _7028,
)
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_GEAR_MESH_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedTimeSteppingAnalysesForModulation",
    "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
)

if TYPE_CHECKING:
    from mastapy.system_model.connections_and_sockets.gears import _2327
    from mastapy.system_model.analyses_and_results.static_loads import _6964
    from mastapy.system_model.analyses_and_results.system_deflections import _2816
    from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
        _7015,
        _7044,
        _7070,
        _7077,
        _7046,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7541, _7538
    from mastapy.system_model.analyses_and_results import _2649, _2653, _2651


__docformat__ = "restructuredtext en"
__all__ = ("StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",)


Self = TypeVar(
    "Self", bound="StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation"
)


class StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation(
    _7028.BevelGearMeshAdvancedTimeSteppingAnalysisForModulation
):
    """StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation

    This is a mastapy class.
    """

    TYPE = _STRAIGHT_BEVEL_GEAR_MESH_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION
    _CastSelf = TypeVar(
        "_CastSelf",
        bound="_Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
    )

    class _Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation:
        """Special nested class for casting StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation to subclasses."""

        def __init__(
            self: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
            parent: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
        ):
            self._parent = parent

        @property
        def bevel_gear_mesh_advanced_time_stepping_analysis_for_modulation(
            self: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_7028.BevelGearMeshAdvancedTimeSteppingAnalysisForModulation":
            return self._parent._cast(
                _7028.BevelGearMeshAdvancedTimeSteppingAnalysisForModulation
            )

        @property
        def agma_gleason_conical_gear_mesh_advanced_time_stepping_analysis_for_modulation(
            self: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
        ) -> (
            "_7015.AGMAGleasonConicalGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ):
            from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
                _7015,
            )

            return self._parent._cast(
                _7015.AGMAGleasonConicalGearMeshAdvancedTimeSteppingAnalysisForModulation
            )

        @property
        def conical_gear_mesh_advanced_time_stepping_analysis_for_modulation(
            self: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_7044.ConicalGearMeshAdvancedTimeSteppingAnalysisForModulation":
            from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
                _7044,
            )

            return self._parent._cast(
                _7044.ConicalGearMeshAdvancedTimeSteppingAnalysisForModulation
            )

        @property
        def gear_mesh_advanced_time_stepping_analysis_for_modulation(
            self: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_7070.GearMeshAdvancedTimeSteppingAnalysisForModulation":
            from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
                _7070,
            )

            return self._parent._cast(
                _7070.GearMeshAdvancedTimeSteppingAnalysisForModulation
            )

        @property
        def inter_mountable_component_connection_advanced_time_stepping_analysis_for_modulation(
            self: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_7077.InterMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation":
            from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
                _7077,
            )

            return self._parent._cast(
                _7077.InterMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation
            )

        @property
        def connection_advanced_time_stepping_analysis_for_modulation(
            self: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_7046.ConnectionAdvancedTimeSteppingAnalysisForModulation":
            from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
                _7046,
            )

            return self._parent._cast(
                _7046.ConnectionAdvancedTimeSteppingAnalysisForModulation
            )

        @property
        def connection_static_load_analysis_case(
            self: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_7541.ConnectionStaticLoadAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7541

            return self._parent._cast(_7541.ConnectionStaticLoadAnalysisCase)

        @property
        def connection_analysis_case(
            self: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_7538.ConnectionAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7538

            return self._parent._cast(_7538.ConnectionAnalysisCase)

        @property
        def connection_analysis(
            self: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_2649.ConnectionAnalysis":
            from mastapy.system_model.analyses_and_results import _2649

            return self._parent._cast(_2649.ConnectionAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_2653.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2653

            return self._parent._cast(_2653.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def straight_bevel_gear_mesh_advanced_time_stepping_analysis_for_modulation(
            self: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
        ) -> "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation":
            return self._parent

        def __getattr__(
            self: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self,
        instance_to_wrap: "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation.TYPE",
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(self: Self) -> "_2327.StraightBevelGearMesh":
        """mastapy.system_model.connections_and_sockets.gears.StraightBevelGearMesh

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def connection_load_case(self: Self) -> "_6964.StraightBevelGearMeshLoadCase":
        """mastapy.system_model.analyses_and_results.static_loads.StraightBevelGearMeshLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionLoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def system_deflection_results(
        self: Self,
    ) -> "_2816.StraightBevelGearMeshSystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.StraightBevelGearMeshSystemDeflection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SystemDeflectionResults

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation":
        return (
            self._Cast_StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation(
                self
            )
        )
